Skip to contents

This function clones the sample-data branch of the BatchPlanet GitHub repository into the current working directory.

Usage

download_sample_data()

Value

Path where the data was downloaded to.

Details

Requires that git is installed and available on your system PATH. If the sample-data folder already exists, the function will not overwrite it.