Download a PlanetScope order
Source:R/download_planetscope_imagery.R
download_planetscope_imagery.RdDownloads all files for a given PlanetScope order ID, saving them to the specified folder. The function will wait until the order is successfully processed by Planet API, partially processed, fail to be processed, or is cancelled.
Examples
if (FALSE) { # \dontrun{
download_planetscope_imagery(
order_id = "abc123-order-id",
exportfolder = "data/raw/SJER/SJER_202405_121_151",
api_key = set_api_key(),
overwrite = TRUE
)
} # }