R/download_sample_data.R
download_sample_data.Rd
This function clones the sample-data branch of the BatchPlanet GitHub repository into the current working directory.
sample-data
download_sample_data()
Path where the data was downloaded to.
Requires that git is installed and available on your system PATH. If the sample-data folder already exists, the function will not overwrite it.
git