Prompts the user to enter a Planet API key and saves it in a hidden .env file in the working directory.
Note
You will need an active Planet account and an API key to access the PlanetScope API. You can sign up for an account on the Planet website. Once you have an account, you can copy your API key from your account settings.